# PyMine-Net
[![CodeFactor](https://www.codefactor.io/repository/github/py-mine/pymine-net/badge)](https://www.codefactor.io/repository/github/py-mine/pymine-net)
![code size](https://img.shields.io/github/languages/code-size/py-mine/PyMine-Net?color=0FAE6E)
![code style](https://img.shields.io/badge/code%20style-black-000000.svg)

*PyMine-Net - an extensible and modular Minecraft networking library in Python*

## Features
- Buffer class with methods for dealing with various types and data formats used by Minecraft
- High level abstractions for packets with a system to seperate different protocol's packets
- Miscellaneous classes for dealing with different Minecraft data structures relevant to networking
